---
route: ~~BASE_URL~~/{{page_name}}
title: {{page_name}} # provide the title
template: index.html # provide jinja2 template for this website
author: YOU
menu: 
    label: Menu label # this label will appear in menu
    order: 2
panel:
  - type: toc # toc will be available
tags: 
  - put_some_tags
summary: Type here the summary
date: {{date}}
---

# Header

Some description

## Section 1

Some content

## Section 2

### Subsection 2.1

Some content

### Subsection 2.2

Some content